summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-07-29 20:31:56 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-07-29 20:31:56 +0000
commit371cec7c177fe680666af49e9a20df76112aa932 (patch)
tree6c5d18a382ea6ac89bb3bbdbd9c82081347bf1d5
parent2684f4b13713fc9346468bc7f8262ec78c91349e (diff)
downloadATCD-371cec7c177fe680666af49e9a20df76112aa932.tar.gz
*** empty log message ***
-rw-r--r--ace/Asynch_Acceptor.cpp18
1 files changed, 10 insertions, 8 deletions
diff --git a/ace/Asynch_Acceptor.cpp b/ace/Asynch_Acceptor.cpp
index b7d076ab9dd..155343e29f2 100644
--- a/ace/Asynch_Acceptor.cpp
+++ b/ace/Asynch_Acceptor.cpp
@@ -112,21 +112,23 @@ ACE_Asynch_Acceptor<HANDLER>::open (const ACE_INET_Addr &address,
}
template <class HANDLER> void
-ACE_Asynch_Acceptor<HANDLER>::set_handle (ACE_HANDLE listen_socket)
+ACE_Asynch_Acceptor<HANDLER>::set_handle (ACE_HANDLE listen_handle)
{
- // Take ownership of the <listen_socket>
- this->listen_socket_ = listen_socket;
+ // Take ownership of the <listen_handle>
+ this->listen_handle_ = listen_handle;
- // Initialize the ACE_Asynch_Accept
- this->asynch_accept_.set_handle (this->listen_handle_);
-
- return 0;
+ // Reinitialize the ACE_Asynch_Accept
+ if (this->asynch_accept_.open (*this,
+ this->listen_handle_,
+ 0,
+ this->proactor ()) == -1)
+ ACE_ERROR ((LM_ERROR, ASYS_TEXT ("%p\n"), ASYS_TEXT ("ACE_Asynch_Accept::open")));
}
template <class HANDLER> ACE_HANDLE
ACE_Asynch_Acceptor<HANDLER>::get_handle (void) const
{
- return this->listen_socket_;
+ return this->listen_handle_;
}
template <class HANDLER> int